# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .airtable_o_auth_error_response import AirtableOAuthErrorResponse
from .airtable_o_auth_success_response import AirtableOAuthSuccessResponse
from .asana_o_auth_error_response import AsanaOAuthErrorResponse
from .asana_o_auth_success_response import AsanaOAuthSuccessResponse
from .attio_o_auth_error_response import AttioOAuthErrorResponse
from .attio_o_auth_success_response import AttioOAuthSuccessResponse
from .call_tool_response import CallToolResponse
from .call_tool_result import CallToolResult
from .canva_o_auth_error_response import CanvaOAuthErrorResponse
from .canva_o_auth_success_response import CanvaOAuthSuccessResponse
from .click_up_o_auth_error_response import ClickUpOAuthErrorResponse
from .click_up_o_auth_success_response import ClickUpOAuthSuccessResponse
from .close_o_auth_error_response import CloseOAuthErrorResponse
from .close_o_auth_success_response import CloseOAuthSuccessResponse
from .confluence_o_auth_error_response import ConfluenceOAuthErrorResponse
from .confluence_o_auth_success_response import ConfluenceOAuthSuccessResponse
from .connection_type import ConnectionType
from .create_server_response import CreateServerResponse
from .extended_mcp_server import ExtendedMcpServer
from .g_calendar_o_auth_error_response import GCalendarOAuthErrorResponse
from .g_calendar_o_auth_success_response import GCalendarOAuthSuccessResponse
from .g_docs_o_auth_error_response import GDocsOAuthErrorResponse
from .g_docs_o_auth_success_response import GDocsOAuthSuccessResponse
from .g_drive_o_auth_error_response import GDriveOAuthErrorResponse
from .g_drive_o_auth_success_response import GDriveOAuthSuccessResponse
from .g_sheets_o_auth_error_response import GSheetsOAuthErrorResponse
from .g_sheets_o_auth_success_response import GSheetsOAuthSuccessResponse
from .get_auth_metadata_response import GetAuthMetadataResponse
from .get_instance_response import GetInstanceResponse
from .get_mcp_servers_response import GetMcpServersResponse
from .get_o_auth_url_response import GetOAuthUrlResponse
from .get_server_instances_response import GetServerInstancesResponse
from .get_tools_response import GetToolsResponse
from .git_hub_o_auth_error_response import GitHubOAuthErrorResponse
from .gmail_o_auth_error_response import GmailOAuthErrorResponse
from .gmail_o_auth_success_response import GmailOAuthSuccessResponse
from .http_validation_error import HttpValidationError
from .hub_spot_o_auth_error_response import HubSpotOAuthErrorResponse
from .hub_spot_o_auth_success_response import HubSpotOAuthSuccessResponse
from .jira_o_auth_error_response import JiraOAuthErrorResponse
from .jira_o_auth_success_response import JiraOAuthSuccessResponse
from .linear_o_auth_error_response import LinearOAuthErrorResponse
from .linear_o_auth_success_response import LinearOAuthSuccessResponse
from .linked_in_o_auth_error_response import LinkedInOAuthErrorResponse
from .list_tools_response import ListToolsResponse
from .mcp_server import McpServer
from .mcp_server_name import McpServerName
from .notion_o_auth_error_response import NotionOAuthErrorResponse
from .notion_o_auth_success_response import NotionOAuthSuccessResponse
from .o_auth_server_name import OAuthServerName
from .salesforce_o_auth_error_response import SalesforceOAuthErrorResponse
from .salesforce_o_auth_success_response import SalesforceOAuthSuccessResponse
from .server_tool import ServerTool
from .slack_o_auth_error_response import SlackOAuthErrorResponse
from .slack_o_auth_success_response import SlackOAuthSuccessResponse
from .status_response import StatusResponse
from .supabase_o_auth_error_response import SupabaseOAuthErrorResponse
from .supabase_o_auth_success_response import SupabaseOAuthSuccessResponse
from .tool_format import ToolFormat
from .validation_error import ValidationError
from .validation_error_loc_item import ValidationErrorLocItem
from .white_labeling_response import WhiteLabelingResponse
from .word_press_o_auth_error_response import WordPressOAuthErrorResponse
from .word_press_o_auth_success_response import WordPressOAuthSuccessResponse
from .xero_o_auth_error_response import XeroOAuthErrorResponse
from .xero_o_auth_success_response import XeroOAuthSuccessResponse

__all__ = [
    "AirtableOAuthErrorResponse",
    "AirtableOAuthSuccessResponse",
    "AsanaOAuthErrorResponse",
    "AsanaOAuthSuccessResponse",
    "AttioOAuthErrorResponse",
    "AttioOAuthSuccessResponse",
    "CallToolResponse",
    "CallToolResult",
    "CanvaOAuthErrorResponse",
    "CanvaOAuthSuccessResponse",
    "ClickUpOAuthErrorResponse",
    "ClickUpOAuthSuccessResponse",
    "CloseOAuthErrorResponse",
    "CloseOAuthSuccessResponse",
    "ConfluenceOAuthErrorResponse",
    "ConfluenceOAuthSuccessResponse",
    "ConnectionType",
    "CreateServerResponse",
    "ExtendedMcpServer",
    "GCalendarOAuthErrorResponse",
    "GCalendarOAuthSuccessResponse",
    "GDocsOAuthErrorResponse",
    "GDocsOAuthSuccessResponse",
    "GDriveOAuthErrorResponse",
    "GDriveOAuthSuccessResponse",
    "GSheetsOAuthErrorResponse",
    "GSheetsOAuthSuccessResponse",
    "GetAuthMetadataResponse",
    "GetInstanceResponse",
    "GetMcpServersResponse",
    "GetOAuthUrlResponse",
    "GetServerInstancesResponse",
    "GetToolsResponse",
    "GitHubOAuthErrorResponse",
    "GmailOAuthErrorResponse",
    "GmailOAuthSuccessResponse",
    "HttpValidationError",
    "HubSpotOAuthErrorResponse",
    "HubSpotOAuthSuccessResponse",
    "JiraOAuthErrorResponse",
    "JiraOAuthSuccessResponse",
    "LinearOAuthErrorResponse",
    "LinearOAuthSuccessResponse",
    "LinkedInOAuthErrorResponse",
    "ListToolsResponse",
    "McpServer",
    "McpServerName",
    "NotionOAuthErrorResponse",
    "NotionOAuthSuccessResponse",
    "OAuthServerName",
    "SalesforceOAuthErrorResponse",
    "SalesforceOAuthSuccessResponse",
    "ServerTool",
    "SlackOAuthErrorResponse",
    "SlackOAuthSuccessResponse",
    "StatusResponse",
    "SupabaseOAuthErrorResponse",
    "SupabaseOAuthSuccessResponse",
    "ToolFormat",
    "ValidationError",
    "ValidationErrorLocItem",
    "WhiteLabelingResponse",
    "WordPressOAuthErrorResponse",
    "WordPressOAuthSuccessResponse",
    "XeroOAuthErrorResponse",
    "XeroOAuthSuccessResponse",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.call_tool_response import CallToolResponse
from ..types.connection_type import ConnectionType
from ..types.create_server_response import CreateServerResponse
from ..types.get_auth_metadata_response import GetAuthMetadataResponse
from ..types.get_instance_response import GetInstanceResponse
from ..types.get_mcp_servers_response import GetMcpServersResponse
from ..types.get_o_auth_url_response import GetOAuthUrlResponse
from ..types.get_tools_response import GetToolsResponse
from ..types.list_tools_response import ListToolsResponse
from ..types.mcp_server_name import McpServerName
from ..types.status_response import StatusResponse
from ..types.tool_format import ToolFormat
from .raw_client import AsyncRawMcpServerClient, RawMcpServerClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class McpServerClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawMcpServerClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawMcpServerClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawMcpServerClient
        """
        return self._raw_client

    def call_tools(
        self,
        *,
        server_url: str,
        tool_name: str,
        tool_args: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = OMIT,
        connection_type: typing.Optional[ConnectionType] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CallToolResponse:
        """
        Calls a tool on a specific remote MCP server, used for function calling. Eliminates the need for manual MCP code implementation.
        Under the hood, Klavis will instantiates an MCP client and establishes a connection with the remote MCP server to call the tool.

        Parameters
        ----------
        server_url : str
            The full URL for connecting to the MCP server

        tool_name : str
            The name of the tool to call

        tool_args : typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]]
            The input parameters for the tool

        connection_type : typing.Optional[ConnectionType]
            The connection type to use for the MCP server. Default is STREAMABLE_HTTP.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CallToolResponse
            Successful Response

        Examples
        --------
        from klavis import Klavis

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.mcp_server.call_tools(
            server_url="serverUrl",
            tool_name="toolName",
        )
        """
        _response = self._raw_client.call_tools(
            server_url=server_url,
            tool_name=tool_name,
            tool_args=tool_args,
            connection_type=connection_type,
            request_options=request_options,
        )
        return _response.data

    def list_tools(
        self,
        *,
        server_url: str,
        connection_type: typing.Optional[ConnectionType] = OMIT,
        format: typing.Optional[ToolFormat] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ListToolsResponse:
        """
        Lists all tools available for a specific remote MCP server in various AI model formats.

        This eliminates the need for manual MCP code implementation and format conversion.
        Under the hood, Klavis instantiates an MCP client and establishes a connection
        with the remote MCP server to retrieve available tools.

        Parameters
        ----------
        server_url : str
            The full URL for connecting to the MCP server

        connection_type : typing.Optional[ConnectionType]
            The connection type to use for the MCP server. Default is STREAMABLE_HTTP.

        format : typing.Optional[ToolFormat]
            The format to return tools in. Default is MCP Native format for maximum compatibility.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListToolsResponse
            Successful Response

        Examples
        --------
        from klavis import Klavis

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.mcp_server.list_tools(
            server_url="serverUrl",
        )
        """
        _response = self._raw_client.list_tools(
            server_url=server_url, connection_type=connection_type, format=format, request_options=request_options
        )
        return _response.data

    def create_server_instance(
        self,
        *,
        server_name: McpServerName,
        user_id: str,
        platform_name: str,
        connection_type: typing.Optional[ConnectionType] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreateServerResponse:
        """
        Creates a URL for a specified MCP server,
        validating the request with an API key and user details.
        Returns the existing server URL if it already exists for the user.
        If OAuth is configured for the server, also returns the base OAuth authorization URL.

        Parameters
        ----------
        server_name : McpServerName
            The name of the target MCP server. Case-insensitive (e.g., 'google calendar', 'GOOGLE_CALENDAR', 'Google Calendar' are all valid).

        user_id : str
            The identifier for the user requesting the server URL.

        platform_name : str
            The name of the platform associated with the user.

        connection_type : typing.Optional[ConnectionType]
            The connection type to use for the MCP server. Default is STREAMABLE_HTTP.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateServerResponse
            Successful Response

        Examples
        --------
        from klavis import Klavis, McpServerName

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.mcp_server.create_server_instance(
            server_name=McpServerName.AFFINITY,
            user_id="userId",
            platform_name="platformName",
        )
        """
        _response = self._raw_client.create_server_instance(
            server_name=server_name,
            user_id=user_id,
            platform_name=platform_name,
            connection_type=connection_type,
            request_options=request_options,
        )
        return _response.data

    def get_server_instance(
        self, instance_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetInstanceResponse:
        """
        Checks the details of a specific server connection instance using its unique ID and API key,
        returning server details like authentication status and associated server/platform info.

        Parameters
        ----------
        instance_id : str
            The ID of the connection instance whose status is being checked. This is returned by the Create API.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetInstanceResponse
            Successful Response

        Examples
        --------
        from klavis import Klavis

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.mcp_server.get_server_instance(
            instance_id="instance_id",
        )
        """
        _response = self._raw_client.get_server_instance(instance_id, request_options=request_options)
        return _response.data

    def delete_instance_auth(
        self, instance_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> StatusResponse:
        """
        Deletes authentication metadata for a specific server connection instance.

        Parameters
        ----------
        instance_id : str
            The ID of the connection instance to delete auth for.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        StatusResponse
            Successful Response

        Examples
        --------
        from klavis import Klavis

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.mcp_server.delete_instance_auth(
            instance_id="instance_id",
        )
        """
        _response = self._raw_client.delete_instance_auth(instance_id, request_options=request_options)
        return _response.data

    def delete_server_instance(
        self, instance_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> StatusResponse:
        """
        Completely removes a server connection instance using its unique ID,
        deleting all associated data from the system.

        Parameters
        ----------
        instance_id : str
            The ID of the connection instance to delete.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        StatusResponse
            Successful Response

        Examples
        --------
        from klavis import Klavis

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.mcp_server.delete_server_instance(
            instance_id="instance_id",
        )
        """
        _response = self._raw_client.delete_server_instance(instance_id, request_options=request_options)
        return _response.data

    def get_tools(
        self, server_name: McpServerName, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetToolsResponse:
        """
        Get list of tool names for a specific MCP server.
        Mainly used for querying metadata about the MCP server.

        Parameters
        ----------
        server_name : McpServerName
            The name of the target MCP server. Case-insensitive (e.g., 'google calendar', 'GOOGLE_CALENDAR', 'Google Calendar' are all valid).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetToolsResponse
            Successful Response

        Examples
        --------
        from klavis import Klavis, McpServerName

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.mcp_server.get_tools(
            server_name=McpServerName.AFFINITY,
        )
        """
        _response = self._raw_client.get_tools(server_name, request_options=request_options)
        return _response.data

    def get_all_mcp_servers(self, *, request_options: typing.Optional[RequestOptions] = None) -> GetMcpServersResponse:
        """
        Get all MCP servers with their basic information including id, name, description, and tools.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetMcpServersResponse
            Successful Response

        Examples
        --------
        from klavis import Klavis

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.mcp_server.get_all_mcp_servers()
        """
        _response = self._raw_client.get_all_mcp_servers(request_options=request_options)
        return _response.data

    def set_instance_auth_token(
        self, *, instance_id: str, auth_token: str, request_options: typing.Optional[RequestOptions] = None
    ) -> StatusResponse:
        """
        Sets an authentication token for a specific instance.
        This updates the auth_metadata for the specified instance.

        Parameters
        ----------
        instance_id : str
            The unique identifier for the connection instance

        auth_token : str
            The authentication token to save

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        StatusResponse
            Successful Response

        Examples
        --------
        from klavis import Klavis

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.mcp_server.set_instance_auth_token(
            instance_id="instanceId",
            auth_token="authToken",
        )
        """
        _response = self._raw_client.set_instance_auth_token(
            instance_id=instance_id, auth_token=auth_token, request_options=request_options
        )
        return _response.data

    def get_instance_auth_metadata(
        self, instance_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetAuthMetadataResponse:
        """
        Retrieves the auth metadata for a specific instance that the API key owner controls.
        Includes access token, refresh token, and other authentication metadata.

        This endpoint includes proper ownership verification to ensure users can only access
        authentication data for instances they own. It also handles token refresh if needed.

        Parameters
        ----------
        instance_id : str
            The ID of the connection instance to get auth metadata for.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetAuthMetadataResponse
            Successful Response

        Examples
        --------
        from klavis import Klavis

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.mcp_server.get_instance_auth_metadata(
            instance_id="instance_id",
        )
        """
        _response = self._raw_client.get_instance_auth_metadata(instance_id, request_options=request_options)
        return _response.data

    def get_o_auth_url(
        self,
        *,
        server_name: McpServerName,
        instance_id: str,
        client_id: typing.Optional[str] = OMIT,
        scope: typing.Optional[str] = OMIT,
        redirect_url: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOAuthUrlResponse:
        """
        Gets the OAuth authorization URL for a specific MCP server and instance.
        Returns the complete OAuth URL with the instance ID as a query parameter.

        Parameters
        ----------
        server_name : McpServerName
            The name of the target MCP server. Case-insensitive (e.g., 'google calendar', 'GOOGLE_CALENDAR', 'Google Calendar' are all valid).

        instance_id : str
            The unique identifier for the connection instance.

        client_id : typing.Optional[str]
            Optional client ID for white labeling. If not provided, will use default credentials.

        scope : typing.Optional[str]
            Optional OAuth scopes to request (comma-separated string).

        redirect_url : typing.Optional[str]
            Optional URL to redirect to after authorization completes.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOAuthUrlResponse
            Successful Response

        Examples
        --------
        from klavis import Klavis, McpServerName

        client = Klavis(
            api_key="YOUR_API_KEY",
        )
        client.mcp_server.get_o_auth_url(
            server_name=McpServerName.AFFINITY,
            instance_id="instanceId",
        )
        """
        _response = self._raw_client.get_o_auth_url(
            server_name=server_name,
            instance_id=instance_id,
            client_id=client_id,
            scope=scope,
            redirect_url=redirect_url,
            request_options=request_options,
        )
        return _response.data


class AsyncMcpServerClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawMcpServerClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawMcpServerClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawMcpServerClient
        """
        return self._raw_client

    async def call_tools(
        self,
        *,
        server_url: str,
        tool_name: str,
        tool_args: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = OMIT,
        connection_type: typing.Optional[ConnectionType] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CallToolResponse:
        """
        Calls a tool on a specific remote MCP server, used for function calling. Eliminates the need for manual MCP code implementation.
        Under the hood, Klavis will instantiates an MCP client and establishes a connection with the remote MCP server to call the tool.

        Parameters
        ----------
        server_url : str
            The full URL for connecting to the MCP server

        tool_name : str
            The name of the tool to call

        tool_args : typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]]
            The input parameters for the tool

        connection_type : typing.Optional[ConnectionType]
            The connection type to use for the MCP server. Default is STREAMABLE_HTTP.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CallToolResponse
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.mcp_server.call_tools(
                server_url="serverUrl",
                tool_name="toolName",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.call_tools(
            server_url=server_url,
            tool_name=tool_name,
            tool_args=tool_args,
            connection_type=connection_type,
            request_options=request_options,
        )
        return _response.data

    async def list_tools(
        self,
        *,
        server_url: str,
        connection_type: typing.Optional[ConnectionType] = OMIT,
        format: typing.Optional[ToolFormat] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ListToolsResponse:
        """
        Lists all tools available for a specific remote MCP server in various AI model formats.

        This eliminates the need for manual MCP code implementation and format conversion.
        Under the hood, Klavis instantiates an MCP client and establishes a connection
        with the remote MCP server to retrieve available tools.

        Parameters
        ----------
        server_url : str
            The full URL for connecting to the MCP server

        connection_type : typing.Optional[ConnectionType]
            The connection type to use for the MCP server. Default is STREAMABLE_HTTP.

        format : typing.Optional[ToolFormat]
            The format to return tools in. Default is MCP Native format for maximum compatibility.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListToolsResponse
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.mcp_server.list_tools(
                server_url="serverUrl",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list_tools(
            server_url=server_url, connection_type=connection_type, format=format, request_options=request_options
        )
        return _response.data

    async def create_server_instance(
        self,
        *,
        server_name: McpServerName,
        user_id: str,
        platform_name: str,
        connection_type: typing.Optional[ConnectionType] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreateServerResponse:
        """
        Creates a URL for a specified MCP server,
        validating the request with an API key and user details.
        Returns the existing server URL if it already exists for the user.
        If OAuth is configured for the server, also returns the base OAuth authorization URL.

        Parameters
        ----------
        server_name : McpServerName
            The name of the target MCP server. Case-insensitive (e.g., 'google calendar', 'GOOGLE_CALENDAR', 'Google Calendar' are all valid).

        user_id : str
            The identifier for the user requesting the server URL.

        platform_name : str
            The name of the platform associated with the user.

        connection_type : typing.Optional[ConnectionType]
            The connection type to use for the MCP server. Default is STREAMABLE_HTTP.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateServerResponse
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis, McpServerName

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.mcp_server.create_server_instance(
                server_name=McpServerName.AFFINITY,
                user_id="userId",
                platform_name="platformName",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create_server_instance(
            server_name=server_name,
            user_id=user_id,
            platform_name=platform_name,
            connection_type=connection_type,
            request_options=request_options,
        )
        return _response.data

    async def get_server_instance(
        self, instance_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetInstanceResponse:
        """
        Checks the details of a specific server connection instance using its unique ID and API key,
        returning server details like authentication status and associated server/platform info.

        Parameters
        ----------
        instance_id : str
            The ID of the connection instance whose status is being checked. This is returned by the Create API.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetInstanceResponse
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.mcp_server.get_server_instance(
                instance_id="instance_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_server_instance(instance_id, request_options=request_options)
        return _response.data

    async def delete_instance_auth(
        self, instance_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> StatusResponse:
        """
        Deletes authentication metadata for a specific server connection instance.

        Parameters
        ----------
        instance_id : str
            The ID of the connection instance to delete auth for.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        StatusResponse
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.mcp_server.delete_instance_auth(
                instance_id="instance_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete_instance_auth(instance_id, request_options=request_options)
        return _response.data

    async def delete_server_instance(
        self, instance_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> StatusResponse:
        """
        Completely removes a server connection instance using its unique ID,
        deleting all associated data from the system.

        Parameters
        ----------
        instance_id : str
            The ID of the connection instance to delete.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        StatusResponse
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.mcp_server.delete_server_instance(
                instance_id="instance_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete_server_instance(instance_id, request_options=request_options)
        return _response.data

    async def get_tools(
        self, server_name: McpServerName, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetToolsResponse:
        """
        Get list of tool names for a specific MCP server.
        Mainly used for querying metadata about the MCP server.

        Parameters
        ----------
        server_name : McpServerName
            The name of the target MCP server. Case-insensitive (e.g., 'google calendar', 'GOOGLE_CALENDAR', 'Google Calendar' are all valid).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetToolsResponse
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis, McpServerName

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.mcp_server.get_tools(
                server_name=McpServerName.AFFINITY,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_tools(server_name, request_options=request_options)
        return _response.data

    async def get_all_mcp_servers(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetMcpServersResponse:
        """
        Get all MCP servers with their basic information including id, name, description, and tools.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetMcpServersResponse
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.mcp_server.get_all_mcp_servers()


        asyncio.run(main())
        """
        _response = await self._raw_client.get_all_mcp_servers(request_options=request_options)
        return _response.data

    async def set_instance_auth_token(
        self, *, instance_id: str, auth_token: str, request_options: typing.Optional[RequestOptions] = None
    ) -> StatusResponse:
        """
        Sets an authentication token for a specific instance.
        This updates the auth_metadata for the specified instance.

        Parameters
        ----------
        instance_id : str
            The unique identifier for the connection instance

        auth_token : str
            The authentication token to save

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        StatusResponse
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.mcp_server.set_instance_auth_token(
                instance_id="instanceId",
                auth_token="authToken",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.set_instance_auth_token(
            instance_id=instance_id, auth_token=auth_token, request_options=request_options
        )
        return _response.data

    async def get_instance_auth_metadata(
        self, instance_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> GetAuthMetadataResponse:
        """
        Retrieves the auth metadata for a specific instance that the API key owner controls.
        Includes access token, refresh token, and other authentication metadata.

        This endpoint includes proper ownership verification to ensure users can only access
        authentication data for instances they own. It also handles token refresh if needed.

        Parameters
        ----------
        instance_id : str
            The ID of the connection instance to get auth metadata for.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetAuthMetadataResponse
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.mcp_server.get_instance_auth_metadata(
                instance_id="instance_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_instance_auth_metadata(instance_id, request_options=request_options)
        return _response.data

    async def get_o_auth_url(
        self,
        *,
        server_name: McpServerName,
        instance_id: str,
        client_id: typing.Optional[str] = OMIT,
        scope: typing.Optional[str] = OMIT,
        redirect_url: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> GetOAuthUrlResponse:
        """
        Gets the OAuth authorization URL for a specific MCP server and instance.
        Returns the complete OAuth URL with the instance ID as a query parameter.

        Parameters
        ----------
        server_name : McpServerName
            The name of the target MCP server. Case-insensitive (e.g., 'google calendar', 'GOOGLE_CALENDAR', 'Google Calendar' are all valid).

        instance_id : str
            The unique identifier for the connection instance.

        client_id : typing.Optional[str]
            Optional client ID for white labeling. If not provided, will use default credentials.

        scope : typing.Optional[str]
            Optional OAuth scopes to request (comma-separated string).

        redirect_url : typing.Optional[str]
            Optional URL to redirect to after authorization completes.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        GetOAuthUrlResponse
            Successful Response

        Examples
        --------
        import asyncio

        from klavis import AsyncKlavis, McpServerName

        client = AsyncKlavis(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.mcp_server.get_o_auth_url(
                server_name=McpServerName.AFFINITY,
                instance_id="instanceId",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_o_auth_url(
            server_name=server_name,
            instance_id=instance_id,
            client_id=client_id,
            scope=scope,
            redirect_url=redirect_url,
            request_options=request_options,
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class OAuthServerName(str, enum.Enum):
    AIRTABLE = "Airtable"
    ASANA = "Asana"
    ATTIO = "Attio"
    CANVA = "Canva"
    CLICK_UP = "ClickUp"
    CLOSE = "Close"
    CONFLUENCE = "Confluence"
    GIT_HUB = "GitHub"
    GMAIL = "Gmail"
    GOOGLE_CALENDAR = "Google Calendar"
    GOOGLE_DOCS = "Google Docs"
    GOOGLE_DRIVE = "Google Drive"
    GOOGLE_SHEETS = "Google Sheets"
    HUB_SPOT = "HubSpot"
    JIRA = "Jira"
    LINEAR = "Linear"
    LINKED_IN = "LinkedIn"
    NOTION = "Notion"
    SALESFORCE = "Salesforce"
    SLACK = "Slack"
    SUPABASE = "Supabase"
    XERO = "Xero"
    WORD_PRESS = "WordPress"

    def visit(
        self,
        airtable: typing.Callable[[], T_Result],
        asana: typing.Callable[[], T_Result],
        attio: typing.Callable[[], T_Result],
        canva: typing.Callable[[], T_Result],
        click_up: typing.Callable[[], T_Result],
        close: typing.Callable[[], T_Result],
        confluence: typing.Callable[[], T_Result],
        git_hub: typing.Callable[[], T_Result],
        gmail: typing.Callable[[], T_Result],
        google_calendar: typing.Callable[[], T_Result],
        google_docs: typing.Callable[[], T_Result],
        google_drive: typing.Callable[[], T_Result],
        google_sheets: typing.Callable[[], T_Result],
        hub_spot: typing.Callable[[], T_Result],
        jira: typing.Callable[[], T_Result],
        linear: typing.Callable[[], T_Result],
        linked_in: typing.Callable[[], T_Result],
        notion: typing.Callable[[], T_Result],
        salesforce: typing.Callable[[], T_Result],
        slack: typing.Callable[[], T_Result],
        supabase: typing.Callable[[], T_Result],
        xero: typing.Callable[[], T_Result],
        word_press: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is OAuthServerName.AIRTABLE:
            return airtable()
        if self is OAuthServerName.ASANA:
            return asana()
        if self is OAuthServerName.ATTIO:
            return attio()
        if self is OAuthServerName.CANVA:
            return canva()
        if self is OAuthServerName.CLICK_UP:
            return click_up()
        if self is OAuthServerName.CLOSE:
            return close()
        if self is OAuthServerName.CONFLUENCE:
            return confluence()
        if self is OAuthServerName.GIT_HUB:
            return git_hub()
        if self is OAuthServerName.GMAIL:
            return gmail()
        if self is OAuthServerName.GOOGLE_CALENDAR:
            return google_calendar()
        if self is OAuthServerName.GOOGLE_DOCS:
            return google_docs()
        if self is OAuthServerName.GOOGLE_DRIVE:
            return google_drive()
        if self is OAuthServerName.GOOGLE_SHEETS:
            return google_sheets()
        if self is OAuthServerName.HUB_SPOT:
            return hub_spot()
        if self is OAuthServerName.JIRA:
            return jira()
        if self is OAuthServerName.LINEAR:
            return linear()
        if self is OAuthServerName.LINKED_IN:
            return linked_in()
        if self is OAuthServerName.NOTION:
            return notion()
        if self is OAuthServerName.SALESFORCE:
            return salesforce()
        if self is OAuthServerName.SLACK:
            return slack()
        if self is OAuthServerName.SUPABASE:
            return supabase()
        if self is OAuthServerName.XERO:
            return xero()
        if self is OAuthServerName.WORD_PRESS:
            return word_press()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class McpServerName(str, enum.Enum):
    AFFINITY = "Affinity"
    AIRTABLE = "Airtable"
    ASANA = "Asana"
    ATTIO = "Attio"
    CLICK_UP = "ClickUp"
    CLOSE = "Close"
    CONFLUENCE = "Confluence"
    DISCORD = "Discord"
    DOC2MARKDOWN = "Doc2markdown"
    FIRECRAWL_DEEP_RESEARCH = "Firecrawl Deep Research"
    FIRECRAWL_WEB_SEARCH = "Firecrawl Web Search"
    GITHUB = "GitHub"
    GMAIL = "Gmail"
    GONG = "Gong"
    GOOGLE_CALENDAR = "Google Calendar"
    GOOGLE_DOCS = "Google Docs"
    GOOGLE_DRIVE = "Google Drive"
    GOOGLE_SHEETS = "Google Sheets"
    HUB_SPOT = "HubSpot"
    JIRA = "Jira"
    KLAVIS_REPORT_GEN = "Klavis ReportGen"
    LINEAR = "Linear"
    LINKED_IN = "LinkedIn"
    MARKDOWN2DOC = "Markdown2doc"
    NOTION = "Notion"
    PLAI = "Plai"
    POSTGRES = "Postgres"
    RESEND = "Resend"
    SALESFORCE = "Salesforce"
    SLACK = "Slack"
    SUPABASE = "Supabase"
    WHATS_APP = "WhatsApp"
    WORD_PRESS = "WordPress"
    YOUTUBE = "YouTube"

    def visit(
        self,
        affinity: typing.Callable[[], T_Result],
        airtable: typing.Callable[[], T_Result],
        asana: typing.Callable[[], T_Result],
        attio: typing.Callable[[], T_Result],
        click_up: typing.Callable[[], T_Result],
        close: typing.Callable[[], T_Result],
        confluence: typing.Callable[[], T_Result],
        discord: typing.Callable[[], T_Result],
        doc2markdown: typing.Callable[[], T_Result],
        firecrawl_deep_research: typing.Callable[[], T_Result],
        firecrawl_web_search: typing.Callable[[], T_Result],
        github: typing.Callable[[], T_Result],
        gmail: typing.Callable[[], T_Result],
        gong: typing.Callable[[], T_Result],
        google_calendar: typing.Callable[[], T_Result],
        google_docs: typing.Callable[[], T_Result],
        google_drive: typing.Callable[[], T_Result],
        google_sheets: typing.Callable[[], T_Result],
        hub_spot: typing.Callable[[], T_Result],
        jira: typing.Callable[[], T_Result],
        klavis_report_gen: typing.Callable[[], T_Result],
        linear: typing.Callable[[], T_Result],
        linked_in: typing.Callable[[], T_Result],
        markdown2doc: typing.Callable[[], T_Result],
        notion: typing.Callable[[], T_Result],
        plai: typing.Callable[[], T_Result],
        postgres: typing.Callable[[], T_Result],
        resend: typing.Callable[[], T_Result],
        salesforce: typing.Callable[[], T_Result],
        slack: typing.Callable[[], T_Result],
        supabase: typing.Callable[[], T_Result],
        whats_app: typing.Callable[[], T_Result],
        word_press: typing.Callable[[], T_Result],
        youtube: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is McpServerName.AFFINITY:
            return affinity()
        if self is McpServerName.AIRTABLE:
            return airtable()
        if self is McpServerName.ASANA:
            return asana()
        if self is McpServerName.ATTIO:
            return attio()
        if self is McpServerName.CLICK_UP:
            return click_up()
        if self is McpServerName.CLOSE:
            return close()
        if self is McpServerName.CONFLUENCE:
            return confluence()
        if self is McpServerName.DISCORD:
            return discord()
        if self is McpServerName.DOC2MARKDOWN:
            return doc2markdown()
        if self is McpServerName.FIRECRAWL_DEEP_RESEARCH:
            return firecrawl_deep_research()
        if self is McpServerName.FIRECRAWL_WEB_SEARCH:
            return firecrawl_web_search()
        if self is McpServerName.GITHUB:
            return github()
        if self is McpServerName.GMAIL:
            return gmail()
        if self is McpServerName.GONG:
            return gong()
        if self is McpServerName.GOOGLE_CALENDAR:
            return google_calendar()
        if self is McpServerName.GOOGLE_DOCS:
            return google_docs()
        if self is McpServerName.GOOGLE_DRIVE:
            return google_drive()
        if self is McpServerName.GOOGLE_SHEETS:
            return google_sheets()
        if self is McpServerName.HUB_SPOT:
            return hub_spot()
        if self is McpServerName.JIRA:
            return jira()
        if self is McpServerName.KLAVIS_REPORT_GEN:
            return klavis_report_gen()
        if self is McpServerName.LINEAR:
            return linear()
        if self is McpServerName.LINKED_IN:
            return linked_in()
        if self is McpServerName.MARKDOWN2DOC:
            return markdown2doc()
        if self is McpServerName.NOTION:
            return notion()
        if self is McpServerName.PLAI:
            return plai()
        if self is McpServerName.POSTGRES:
            return postgres()
        if self is McpServerName.RESEND:
            return resend()
        if self is McpServerName.SALESFORCE:
            return salesforce()
        if self is McpServerName.SLACK:
            return slack()
        if self is McpServerName.SUPABASE:
            return supabase()
        if self is McpServerName.WHATS_APP:
            return whats_app()
        if self is McpServerName.WORD_PRESS:
            return word_press()
        if self is McpServerName.YOUTUBE:
            return youtube()



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    AirtableOAuthErrorResponse,
    AirtableOAuthSuccessResponse,
    AsanaOAuthErrorResponse,
    AsanaOAuthSuccessResponse,
    AttioOAuthErrorResponse,
    AttioOAuthSuccessResponse,
    CallToolResponse,
    CallToolResult,
    CanvaOAuthErrorResponse,
    CanvaOAuthSuccessResponse,
    ClickUpOAuthErrorResponse,
    ClickUpOAuthSuccessResponse,
    CloseOAuthErrorResponse,
    CloseOAuthSuccessResponse,
    ConfluenceOAuthErrorResponse,
    ConfluenceOAuthSuccessResponse,
    ConnectionType,
    CreateServerResponse,
    ExtendedMcpServer,
    GCalendarOAuthErrorResponse,
    GCalendarOAuthSuccessResponse,
    GDocsOAuthErrorResponse,
    GDocsOAuthSuccessResponse,
    GDriveOAuthErrorResponse,
    GDriveOAuthSuccessResponse,
    GSheetsOAuthErrorResponse,
    GSheetsOAuthSuccessResponse,
    GetAuthMetadataResponse,
    GetInstanceResponse,
    GetMcpServersResponse,
    GetOAuthUrlResponse,
    GetServerInstancesResponse,
    GetToolsResponse,
    GitHubOAuthErrorResponse,
    GmailOAuthErrorResponse,
    GmailOAuthSuccessResponse,
    HttpValidationError,
    HubSpotOAuthErrorResponse,
    HubSpotOAuthSuccessResponse,
    JiraOAuthErrorResponse,
    JiraOAuthSuccessResponse,
    LinearOAuthErrorResponse,
    LinearOAuthSuccessResponse,
    LinkedInOAuthErrorResponse,
    ListToolsResponse,
    McpServer,
    McpServerName,
    NotionOAuthErrorResponse,
    NotionOAuthSuccessResponse,
    OAuthServerName,
    SalesforceOAuthErrorResponse,
    SalesforceOAuthSuccessResponse,
    ServerTool,
    SlackOAuthErrorResponse,
    SlackOAuthSuccessResponse,
    StatusResponse,
    SupabaseOAuthErrorResponse,
    SupabaseOAuthSuccessResponse,
    ToolFormat,
    ValidationError,
    ValidationErrorLocItem,
    WhiteLabelingResponse,
    WordPressOAuthErrorResponse,
    WordPressOAuthSuccessResponse,
    XeroOAuthErrorResponse,
    XeroOAuthSuccessResponse,
)
from .errors import BadRequestError, UnprocessableEntityError
from . import (
    airtable_oauth,
    asana_oauth,
    attio_oauth,
    canva_oauth,
    clickup_oauth,
    close_oauth,
    confluence_oauth,
    gcalendar_oauth,
    gdocs_oauth,
    gdrive_oauth,
    github_oauth,
    gmail_oauth,
    gsheets_oauth,
    hubspot_oauth,
    jira_oauth,
    linear_oauth,
    linkedin_oauth,
    mcp_server,
    notion_oauth,
    salesforce_oauth,
    slack_oauth,
    supabase_oauth,
    user,
    white_labeling,
    wordpress_oauth,
    xero_oauth,
)
from .client import AsyncKlavis, Klavis
from .environment import KlavisEnvironment
from .version import __version__

__all__ = [
    "AirtableOAuthErrorResponse",
    "AirtableOAuthSuccessResponse",
    "AsanaOAuthErrorResponse",
    "AsanaOAuthSuccessResponse",
    "AsyncKlavis",
    "AttioOAuthErrorResponse",
    "AttioOAuthSuccessResponse",
    "BadRequestError",
    "CallToolResponse",
    "CallToolResult",
    "CanvaOAuthErrorResponse",
    "CanvaOAuthSuccessResponse",
    "ClickUpOAuthErrorResponse",
    "ClickUpOAuthSuccessResponse",
    "CloseOAuthErrorResponse",
    "CloseOAuthSuccessResponse",
    "ConfluenceOAuthErrorResponse",
    "ConfluenceOAuthSuccessResponse",
    "ConnectionType",
    "CreateServerResponse",
    "ExtendedMcpServer",
    "GCalendarOAuthErrorResponse",
    "GCalendarOAuthSuccessResponse",
    "GDocsOAuthErrorResponse",
    "GDocsOAuthSuccessResponse",
    "GDriveOAuthErrorResponse",
    "GDriveOAuthSuccessResponse",
    "GSheetsOAuthErrorResponse",
    "GSheetsOAuthSuccessResponse",
    "GetAuthMetadataResponse",
    "GetInstanceResponse",
    "GetMcpServersResponse",
    "GetOAuthUrlResponse",
    "GetServerInstancesResponse",
    "GetToolsResponse",
    "GitHubOAuthErrorResponse",
    "GmailOAuthErrorResponse",
    "GmailOAuthSuccessResponse",
    "HttpValidationError",
    "HubSpotOAuthErrorResponse",
    "HubSpotOAuthSuccessResponse",
    "JiraOAuthErrorResponse",
    "JiraOAuthSuccessResponse",
    "Klavis",
    "KlavisEnvironment",
    "LinearOAuthErrorResponse",
    "LinearOAuthSuccessResponse",
    "LinkedInOAuthErrorResponse",
    "ListToolsResponse",
    "McpServer",
    "McpServerName",
    "NotionOAuthErrorResponse",
    "NotionOAuthSuccessResponse",
    "OAuthServerName",
    "SalesforceOAuthErrorResponse",
    "SalesforceOAuthSuccessResponse",
    "ServerTool",
    "SlackOAuthErrorResponse",
    "SlackOAuthSuccessResponse",
    "StatusResponse",
    "SupabaseOAuthErrorResponse",
    "SupabaseOAuthSuccessResponse",
    "ToolFormat",
    "UnprocessableEntityError",
    "ValidationError",
    "ValidationErrorLocItem",
    "WhiteLabelingResponse",
    "WordPressOAuthErrorResponse",
    "WordPressOAuthSuccessResponse",
    "XeroOAuthErrorResponse",
    "XeroOAuthSuccessResponse",
    "__version__",
    "airtable_oauth",
    "asana_oauth",
    "attio_oauth",
    "canva_oauth",
    "clickup_oauth",
    "close_oauth",
    "confluence_oauth",
    "gcalendar_oauth",
    "gdocs_oauth",
    "gdrive_oauth",
    "github_oauth",
    "gmail_oauth",
    "gsheets_oauth",
    "hubspot_oauth",
    "jira_oauth",
    "linear_oauth",
    "linkedin_oauth",
    "mcp_server",
    "notion_oauth",
    "salesforce_oauth",
    "slack_oauth",
    "supabase_oauth",
    "user",
    "white_labeling",
    "wordpress_oauth",
    "xero_oauth",
]
